@@ -1,5 +1,8 @@
 package Parse::Number::ID;
 
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -8,8 +11,6 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(parse_number_id $Pat);
 
-our $VERSION = '0.07'; # VERSION
-
 our %SPEC;
 
 #our $Pat = qr/(?:
@@ -89,7 +90,7 @@ Parse::Number::ID - Parse number from Indonesian text
 
 =head1 VERSION
 
-This document describes version 0.07 of Parse::Number::ID (from Perl distribution Parse-Number-ID), released on 2014-10-03.
+This document describes version 0.08 of Parse::Number::ID (from Perl distribution Parse-Number-ID), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -117,19 +118,8 @@ This module does not parse numbers that are written as Indonesian words, e.g.
 "seratus dua puluh tiga" (123). See L<Lingua::ID::Words2Nums> and
 L<Regexp::ID::NumVerbage> for that.
 
-=head1 VARIABLES
-
-None are exported by default, but they are exportable.
-
-=head2 $Pat (regex)
-
-A regex for quickly matching/extracting number from text. It's not 100% perfect
-(the extracted number might not be valid), but it's simple and fast.
-
 =head1 FUNCTIONS
 
-None of the functions are exported by default, but they are exportable.
-
 
 =head2 parse_number_id(%args) -> any
 
@@ -145,9 +135,16 @@ The input text that contains number.
 
 =back
 
-Return value:
+Return value:  (any)
 
- (any)
+=head1 VARIABLES
+
+None are exported by default, but they are exportable.
+
+=head2 $Pat (regex)
+
+A regex for quickly matching/extracting number from text. It's not 100% perfect
+(the extracted number might not be valid), but it's simple and fast.
 
 =head1 FAQ
 
@@ -170,7 +167,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Parse-Numb
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Parse-Number-ID>.
+Source repository is at L<https://github.com/perlancar/perl-Parse-Number-ID>.
 
 =head1 BUGS
 
@@ -186,7 +183,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
